@@ -33,20 +33,21 @@
 
 #include "ThreadPool.h"
 
-#include <cassert>
-#include <cstdio>
-#include <cstdlib>
-
 #if defined(__OSX__) || defined(__APPLE__) || defined(__NetBSD__)
 #include <sys/resource.h>
 #endif
 
+#include <cassert>
+#include <cerrno>
 #include <chrono>
-#include <deque>
-#include <thread>
-#include <mutex>
 #include <condition_variable>
+#include <cstdlib>
+#include <ctime>
+#include <deque>
 #include <iostream>
+#include <mutex>
+#include <thread>
+#include <utility>
 
 using namespace std::chrono;
 
@@ -62,9 +63,8 @@ using namespace std::chrono;
 
 /*! Internal ThreadPool Job. */
 struct ThreadPoolJob {
-    ThreadPoolJob(std::unique_ptr<JobWorker> worker, ThreadPool::ThreadPriority _prio)
-        : m_worker(std::move(worker)), priority(_prio) {}
-    ~ThreadPoolJob() = default;
+    ThreadPoolJob(std::unique_ptr<JobWorker> worker, ThreadPool::ThreadPriority _prio, int j, steady_clock::time_point rt)
+        : m_worker(std::move(worker)), priority(_prio), requestTime(rt), jobId(j) {}
     std::unique_ptr<JobWorker> m_worker;
     ThreadPool::ThreadPriority priority;
     steady_clock::time_point requestTime;
@@ -73,7 +73,7 @@ struct ThreadPoolJob {
 
 class ThreadPool::Internal {
 public:
-    explicit Internal(ThreadPoolAttr *attr);
+    explicit Internal(const ThreadPoolAttr* attr);
     bool ok{false};
     int createWorker(std::unique_lock<std::mutex>& lck);
     void addWorker(std::unique_lock<std::mutex>& lck);
@@ -137,12 +137,11 @@ ThreadPool::~ThreadPool()
     m.release();
 }
 
-int ThreadPool::start(ThreadPoolAttr *attr)
+int ThreadPool::start(const ThreadPoolAttr* attr)
 {
     m = std::make_unique<Internal>(attr);
-    if (m && m->ok) {
+    if (m->ok)
         return 0;
-    }
     return -1;
 }
 
@@ -531,7 +530,7 @@ void ThreadPool::Internal::addWorker(std::unique_lock<std::mutex>& lck)
     }
 }
 
-ThreadPool::Internal::Internal(ThreadPoolAttr *attr)
+ThreadPool::Internal::Internal(const ThreadPoolAttr* attr)
 {
     int retCode = 0;
     int i = 0;
@@ -582,10 +581,7 @@ int ThreadPool::addPersistent(std::unique_ptr<JobWorker> worker, ThreadPriority
             return EMAXTHREADS;
     }
 
-    auto job = std::make_unique<ThreadPoolJob>(std::move(worker), priority);
-    job->jobId = m->lastJobId;
-    job->requestTime = steady_clock::now();
-    m->persistentJob = std::move(job);
+    m->persistentJob = std::make_unique<ThreadPoolJob>(std::move(worker), priority, m->lastJobId, steady_clock::now());
 
     /* Notify a waiting thread */
     m->condition.notify_one();
@@ -608,9 +604,7 @@ int ThreadPool::addJob(std::unique_ptr<JobWorker> worker, ThreadPriority prio)
         return 0;
     }
 
-    auto job = std::make_unique<ThreadPoolJob>(std::move(worker), prio);
-    job->jobId =  m->lastJobId;
-    job->requestTime = steady_clock::now();
+    auto job = std::make_unique<ThreadPoolJob>(std::move(worker), prio, m->lastJobId, steady_clock::now());
     switch (job->priority) {
     case HIGH_PRIORITY:
         m->highJobQ.push_back(std::move(job));
@@ -643,11 +637,10 @@ int ThreadPool::getAttr(ThreadPoolAttr *out)
     return 0;
 }
 
-int ThreadPool::setAttr(ThreadPoolAttr *attr)
+int ThreadPool::setAttr(const ThreadPoolAttr* attr)
 {
     int retCode = 0;
     ThreadPoolAttr temp;
-    int i = 0;
 
     std::unique_lock<std::mutex> lck(m->mutex);
 
@@ -659,7 +652,7 @@ int ThreadPool::setAttr(ThreadPoolAttr *attr)
     m->attr = temp;
     /* add threads */
     if (m->totalThreads < m->attr.minThreads) {
-        for (i = m->totalThreads; i < m->attr.minThreads; i++) {
+        for (auto i = m->totalThreads; i < m->attr.minThreads; i++) {
             retCode = m->createWorker(lck);
             if (retCode != 0) {
                 break;
