@@ -33,34 +33,29 @@
 /* Misc HTTP-related utilities */
 
 #include "config.h"
-
 #include "httputils.h"
 
-#include <cctype>
 #include <cinttypes>
-#include <climits>
-#include <cstdio>
+#include <cstdint>
 #include <cstdlib>
 #include <cstring>
-#include <cstdint>
-
-#include <string>
-#include <sstream>
+#include <ctime>
 #include <iostream>
-#include <map>
+#include <unordered_map>
+#include <sstream>
+#include <string>
 
 #include <curl/curl.h>
+#include <microhttpd.h>
 
-#include "UpnpInet.h"
 #include "genut.h"
 #include "statcodes.h"
 #include "upnp.h"
 #include "upnpdebug.h"
 #include "uri.h"
-#include "upnpapi.h"
 
-static const std::string bogus_soap_post{"SMPOST"};
-static const std::map<std::string, int> Http_Method_Table {
+static constexpr std::string_view bogus_soap_post{"SMPOST"};
+static const std::unordered_map<std::string_view, int> Http_Method_Table {
     {"GET", HTTPMETHOD_GET},
     {"HEAD", HTTPMETHOD_HEAD},
     {"M-POST", HTTPMETHOD_MPOST},
@@ -72,7 +67,7 @@ static const std::map<std::string, int> Http_Method_Table {
     {bogus_soap_post, SOAPMETHOD_POST},
 };
 
-static const std::map<std::string, int> Http_Header_Names {
+static const std::unordered_map<std::string_view, int> Http_Header_Names {
     {"accept", HDR_ACCEPT},
     {"accept-charset", HDR_ACCEPT_CHARSET},
     {"accept-encoding", HDR_ACCEPT_ENCODING},
@@ -112,19 +107,28 @@ void MHDTransaction::copyClientAddress(struct sockaddr_storage *dest) const
 {
     if (nullptr == dest)
         return;
-    if (nullptr == client_address) {
-        *dest = {};
-        return;
-    }
-    if (client_address->ss_family == AF_INET) {
-        memcpy(dest, client_address, sizeof(struct sockaddr_in));
+    if (client_address.ss_family == AF_INET) {
+        memcpy(dest, &client_address, sizeof(struct sockaddr_in));
+    } else if (client_address.ss_family == AF_INET6) {
+        memcpy(dest, &client_address, sizeof(struct sockaddr_in6));
     } else {
-        memcpy(dest, client_address, sizeof(struct sockaddr_in6));
-    }        
+        *dest = {};
+    }
 }
 
-bool MHDTransaction::copyHeader(const std::string& name,
-                                std::string& value)
+void MHDTransaction::copyToClientAddress(const struct sockaddr *src)
+{
+    memset(&client_address, 0, sizeof(client_address));
+    if (nullptr == src)
+        return;
+    if (src->sa_family == AF_INET) {
+        memcpy(&client_address, src, sizeof(struct sockaddr_in));
+    } else if (src->sa_family == AF_INET6) {
+        memcpy(&client_address, src, sizeof(struct sockaddr_in6));
+    }
+}
+
+bool MHDTransaction::copyHeader(const std::string& name, std::string& value)
 {
     auto it = headers.find(stringtolower(name));
     if (it == headers.end()) {
@@ -297,7 +301,7 @@ int http_Download(const char *_surl, int timeout_secs,
 int http_SendStatusResponse(MHDTransaction *mhdt, int status_code)
 {
     std::ostringstream body;
-    body <<    "<html><body><h1>" << status_code << " " << 
+    body << "<html><body><h1>" << status_code << " " << 
         http_get_code_text(status_code) << "</h1></body></html>";
     mhdt->response = MHD_create_response_from_buffer(
         body.str().size(), const_cast<char*>(body.str().c_str()), MHD_RESPMEM_MUST_COPY);
@@ -313,8 +317,7 @@ bool has_xml_content_type(MHDTransaction *mhdt)
 
     auto it = mhdt->headers.find("content-type");
     if (it == mhdt->headers.end()) {
-        UpnpPrintf(UPNP_INFO, HTTP, __FILE__, __LINE__,
-                   "has_xml_content: no content type header\n");
+        UpnpPrintf(UPNP_INFO, HTTP, __FILE__, __LINE__, "has_xml_content: no content type header\n");
         return false;
     }
     if (strncasecmp(xmlmtype, it->second.c_str(), mtlen)) {
@@ -330,8 +333,7 @@ bool timeout_header_value(std::map<std::string, std::string>& headers,
 {
     auto ittimo = headers.find("timeout");
     if (ittimo == headers.end()) {
-        UpnpPrintf(UPNP_INFO, HTTP, __FILE__, __LINE__,
-                   "timeout_header_value: no timeout header\n");
+        UpnpPrintf(UPNP_INFO, HTTP, __FILE__, __LINE__, "timeout_header_value: no timeout header\n");
         return false;
     }
     stringtolower(ittimo->second);
@@ -372,15 +374,14 @@ static const std::string& get_sdk_common_info()
     if (sdk_common_info.empty()) {
         std::ostringstream ostr;
 #ifdef UPNP_ENABLE_UNSPECIFIED_SERVER
-        ostr << "Unspecified UPnP/1.0 Unspecified";
+        ostr << "Unspecified UPnP/1.1 Unspecified";
 #else /* UPNP_ENABLE_UNSPECIFIED_SERVER */
 #ifdef _WIN32
             OSVERSIONINFO versioninfo;
         versioninfo.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
 
         if (GetVersionEx(&versioninfo) != 0)
-            ostr << versioninfo.dwMajorVersion << "." <<
-                versioninfo.dwMinorVersion << "." <<
+            ostr << versioninfo.dwMajorVersion << "." << versioninfo.dwMinorVersion << "." <<
                 versioninfo.dwBuildNumber << " " << versioninfo.dwPlatformId
                  << "/" << versioninfo.szCSDVersion;
 #else
@@ -391,7 +392,7 @@ static const std::string& get_sdk_common_info()
 #endif
 #endif /* UPNP_ENABLE_UNSPECIFIED_SERVER */
 
-        ostr << " UPnP/1.0 ";
+        ostr << " UPnP/1.1 ";
         sdk_common_info = ostr.str();
     }
     return sdk_common_info;
@@ -425,7 +426,7 @@ std::string make_date_string(time_t thetime)
 
     time_t curr_time = thetime ? thetime : time(nullptr);
     struct tm date_storage;
-    struct tm *date = http_gmtime_r(&curr_time, &date_storage);
+    const struct tm *date = http_gmtime_r(&curr_time, &date_storage);
     if (date == nullptr)
         return {};
     char tempbuf[200];
@@ -459,7 +460,8 @@ std::string query_encode(const std::string& qs)
     return out;
 }
 
-size_t header_callback_curl(char *buffer, size_t size, size_t nitems, std::map<std::string, std::string> *headers)
+size_t header_callback_curl(char *buffer, size_t size, size_t nitems,
+                            std::map<std::string, std::string> *headers)
 {
     size_t bufsize = size * nitems;
     const char *colon = std::strchr(buffer, ':');
